@@ -32,8 +32,11 @@ from pathlib import Path
 import numpy as np
 
 from ase import Atoms
-from ase.calculators.calculator import (BaseCalculator, compare_atoms,
-                                        kpts2sizeandoffsets)
+from ase.calculators.calculator import (
+    BaseCalculator,
+    compare_atoms,
+    kpts2sizeandoffsets,
+)
 from ase.config import cfg
 from ase.dft.kpoints import BandPath
 from ase.io.castep import read_bands, read_param
@@ -481,8 +484,8 @@ End CASTEP Interface Documentation
 
         self.results = {}
 
-        from ase.io.castep import write_cell
-        self._write_cell = write_cell
+        from ase.io.castep import write_castep_cell
+        self._write_cell = write_castep_cell
 
         if castep_keywords is None:
             castep_keywords = CastepKeywords(make_param_dict(),
@@ -630,7 +633,7 @@ End CASTEP Interface Documentation
         if not os.path.exists(bandfile):
             raise ValueError(f'Cannot find band file "{bandfile}".')
 
-        kpts, weights, eigenvalues, efermi = read_bands(bandfile)
+        kpts, _weights, eigenvalues, efermi = read_bands(bandfile)
 
         # Get definitions of high-symmetry points
         special_points = self.atoms.cell.bandpath(npoints=0).special_points
@@ -1203,9 +1206,12 @@ End CASTEP Interface Documentation
         self._castep_file = self._abs_path(f'{self._seed}.castep')
 
         # write out the input file
+        magnetic_moments = ('initial' if
+                            self.param.spin_polarized.value == 'TRUE'
+                            else None)
         self._write_cell(self._abs_path(f'{self._seed}.cell'),
                          self.atoms, castep_cell=self.cell,
-                         force_write=force_write)
+                         magnetic_moments=magnetic_moments)
 
         if self._export_settings:
             interface_options = self._opt
@@ -1440,8 +1446,12 @@ End CASTEP Interface Documentation
         self._fetch_pspots(temp_dir)
         seed = 'dryrun'
 
+        magnetic_moments = ('initial' if
+                            self.param.spin_polarized.value == 'TRUE'
+                            else None)
         self._write_cell(os.path.join(temp_dir, f'{seed}.cell'),
-                         self.atoms, castep_cell=self.cell)
+                         self.atoms, castep_cell=self.cell,
+                         magnetic_moments=magnetic_moments)
         # This part needs to be modified now that we rely on the new formats.py
         # interface
         if not os.path.isfile(os.path.join(temp_dir, f'{seed}.cell')):
