@@ -13,8 +13,12 @@ from warnings import warn
 import numpy as np
 
 import ase.io
-from ase.calculators.calculator import (Calculator, CalculatorSetupError,
-                                        Parameters, all_changes)
+from ase.calculators.calculator import (
+    Calculator,
+    CalculatorSetupError,
+    Parameters,
+    all_changes,
+)
 from ase.config import cfg
 from ase.units import Rydberg
 
