@@ -5,8 +5,11 @@ from warnings import warn
 
 import numpy as np
 
-from ase.calculators.calculator import (BaseCalculator, Calculator,
-                                        FileIOCalculator)
+from ase.calculators.calculator import (
+    BaseCalculator,
+    Calculator,
+    FileIOCalculator,
+)
 from ase.io import write
 from ase.io.vasp import write_vasp
 from ase.parallel import world
@@ -267,7 +270,7 @@ class PureDFTD3(FileIOCalculator):
         # If a parameter file exists in the working directory, delete it
         # first. If we need that file, we'll recreate it later.
         localparfile = os.path.join(self.directory, '.dftd3par.local')
-        if world.rank == 0 and os.path.isfile(localparfile):
+        if self.comm.rank == 0 and os.path.isfile(localparfile):
             os.remove(localparfile)
 
         # Write XYZ or POSCAR file and .dftd3par.local file if we are using
