@@ -14,6 +14,7 @@ import numpy as np
 from scipy.interpolate import InterpolatedUnivariateSpline as spline
 
 from ase.calculators.calculator import Calculator, all_changes
+from ase.data import chemical_symbols
 from ase.neighborlist import NeighborList
 from ase.units import Bohr, Hartree
 
@@ -317,6 +318,7 @@ End EAM Interface Documentation
             # eam form is just like an alloy form for one element
 
             self.Nelements = 1
+            self.elements = [chemical_symbols[int(data[0])]]
             self.Z = np.array([data[0]], dtype=int)
             self.mass = np.array([data[1]])
             self.a = np.array([data[2]])
