@@ -3,9 +3,13 @@ from numpy.linalg import eigh, norm, pinv
 from scipy.linalg import lstsq  # performs better than numpy.linalg.lstsq
 
 from ase import units
-from ase.calculators.calculator import (BaseCalculator, CalculationFailed,
-                                        Calculator, CalculatorSetupError,
-                                        all_changes)
+from ase.calculators.calculator import (
+    BaseCalculator,
+    CalculationFailed,
+    Calculator,
+    CalculatorSetupError,
+    all_changes,
+)
 
 
 class HarmonicCalculator(BaseCalculator):
