@@ -10,8 +10,12 @@ from abc import ABC
 
 import numpy as np
 
-from .exceptions import (KIMModelInitializationError, KIMModelNotFound,
-                         KIMModelParameterError, KimpyError)
+from .exceptions import (
+    KIMModelInitializationError,
+    KIMModelNotFound,
+    KIMModelParameterError,
+    KimpyError,
+)
 
 
 class LazyKimpyImport:
