@@ -1,8 +1,10 @@
 import importlib
 from typing import List, Tuple
 
-from ase.utils import (get_python_package_path_description,
-                       search_current_git_hash)
+from ase.utils import (
+    get_python_package_path_description,
+    search_current_git_hash,
+)
 
 
 def format_dependency(modname: str) -> Tuple[str, str]:
