@@ -3,8 +3,11 @@ import numpy as np
 
 from ase import Atoms
 from ase.ga.offspring_creator import OffspringCreator
-from ase.ga.utilities import (atoms_too_close, atoms_too_close_two_sets,
-                              gather_atoms_by_tag)
+from ase.ga.utilities import (
+    atoms_too_close,
+    atoms_too_close_two_sets,
+    gather_atoms_by_tag,
+)
 from ase.geometry import find_mic
 
 
@@ -466,7 +469,7 @@ class CutAndSplicePairing(OffspringCreator):
             c = a1.get_cell() if p.origin == 0 else a2.get_cell()
             pos = np.dot(p.scaled_positions, c)
             cop = np.dot(p.cop, c)
-            vectors, lengths = find_mic(pos - cop, c, pbc)
+            vectors, _lengths = find_mic(pos - cop, c, pbc)
             newcop = np.dot(p.cop, cell)
             pos = newcop + vectors
             for row in pos:
