@@ -451,7 +451,7 @@ class OFPComparator:
             fp, typedic = self._take_fingerprints(a_top, individual=True)
             a.info[key] = self._json_encode(fp, typedic)
 
-        volume, pmin, pmax, qmin, qmax = self._get_volume(a_top)
+        volume, _pmin, _pmax, _qmin, _qmax = self._get_volume(a_top)
         return self._calculate_local_orders(fp, typedic, volume)
 
     def _cosine_distance(self, fp1, fp2, typedic):
