@@ -1,6 +1,5 @@
-from ase.io.ulm import DummyWriter
+from ase.io.ulm import DummyWriter, Reader, Writer
 from ase.io.ulm import InvalidULMFileError as InvalidAFFError
-from ase.io.ulm import Reader, Writer
 from ase.io.ulm import open as affopen
 
 __all__ = ['affopen', 'InvalidAFFError',
