@@ -3,6 +3,7 @@ import os
 import re
 import time
 import warnings
+from functools import cached_property
 from pathlib import Path
 from typing import Any, Dict, List, Union
 
@@ -15,7 +16,7 @@ from ase.constraints import FixAtoms, FixCartesian
 from ase.data import atomic_numbers
 from ase.io import ParseError
 from ase.units import Ang, fs
-from ase.utils import deprecated, lazymethod, lazyproperty, reader, writer
+from ase.utils import deprecated, reader, writer
 
 v_unit = Ang / (1000.0 * fs)
 
@@ -49,9 +50,12 @@ def read_aims(fd, apply_constraints=True):
 def parse_geometry_lines(lines, apply_constraints=True):
 
     from ase import Atoms
-    from ase.constraints import (FixAtoms, FixCartesian,
-                                 FixCartesianParametricRelations,
-                                 FixScaledParametricRelations)
+    from ase.constraints import (
+        FixAtoms,
+        FixCartesian,
+        FixCartesianParametricRelations,
+        FixScaledParametricRelations,
+    )
 
     atoms = Atoms()
 
@@ -376,8 +380,10 @@ def write_aims(
 
 def get_sym_block(atoms):
     """Get symmetry block for Parametric constraints in atoms.constraints"""
-    from ase.constraints import (FixCartesianParametricRelations,
-                                 FixScaledParametricRelations)
+    from ase.constraints import (
+        FixCartesianParametricRelations,
+        FixScaledParametricRelations,
+    )
 
     # Initialize param/expressions lists
     atomic_sym_params = []
@@ -484,7 +490,7 @@ def format_aims_control_parameter(key, value, format="%s"):
     str
         The properly formatted line for the aims control.in
     """
-    return f"{key :35s}" + (format % value) + "\n"
+    return f"{key:35s}" + (format % value) + "\n"
 
 
 # Write aims control.in files
@@ -541,6 +547,8 @@ def write_control(fd, atoms, parameters, verbose_header=False):
                     "%f %f %f"))
         elif key in ("species_dir", "tier"):
             continue
+        elif key == "aims_command":
+            continue
         elif key == "plus_u":
             continue
         elif key == "smearing":
@@ -867,10 +875,8 @@ class AimsOutHeaderChunk(AimsOutChunk):
             The lines inside the aims.out header
         """
         super().__init__(lines)
-        self._k_points = None
-        self._k_point_weights = None
 
-    @lazyproperty
+    @cached_property
     def constraints(self):
         """Parse the constraints from the aims.out file
 
@@ -912,7 +918,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
 
         return fix_cart
 
-    @lazyproperty
+    @cached_property
     def initial_cell(self):
         """Parse the initial cell from the aims.out file"""
         line_start = self.reverse_search_for(["| Unit cell:"])
@@ -924,7 +930,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
             for line in self.lines[line_start + 1:line_start + 4]
         ]
 
-    @lazyproperty
+    @cached_property
     def initial_atoms(self):
         """Create an atoms object for the initial geometry.in structure
         from the aims.out file"""
@@ -953,21 +959,21 @@ class AimsOutHeaderChunk(AimsOutChunk):
 
         return atoms
 
-    @lazyproperty
+    @cached_property
     def is_md(self):
         """Determine if calculation is a molecular dynamics calculation"""
         return LINE_NOT_FOUND != self.reverse_search_for(
             ["Complete information for previous time-step:"]
         )
 
-    @lazyproperty
+    @cached_property
     def is_relaxation(self):
         """Determine if the calculation is a geometry optimization or not"""
         return LINE_NOT_FOUND != self.reverse_search_for(
             ["Geometry relaxation:"])
 
-    @lazymethod
-    def _parse_k_points(self):
+    @cached_property
+    def _k_points(self):
         """Get the list of k-points used in the calculation"""
         n_kpts = self.parse_scalar("n_kpts")
         if n_kpts is None:
@@ -1000,7 +1006,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
             "k_point_weights": k_point_weights,
         }
 
-    @lazyproperty
+    @cached_property
     def n_atoms(self):
         """The number of atoms for the material"""
         n_atoms = self.parse_scalar("n_atoms")
@@ -1010,7 +1016,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
             )
         return int(n_atoms)
 
-    @lazyproperty
+    @cached_property
     def n_bands(self):
         """The number of Kohn-Sham states for the chunk"""
         line_start = self.reverse_search_for(
@@ -1027,7 +1033,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
 
         return int(line.split()[-1].strip()[:-1])
 
-    @lazyproperty
+    @cached_property
     def n_electrons(self):
         """The number of electrons for the chunk"""
         line_start = self.reverse_search_for(
@@ -1041,7 +1047,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
         line = self.lines[line_start]
         return int(float(line.split()[-2]))
 
-    @lazyproperty
+    @cached_property
     def n_k_points(self):
         """The number of k_ppoints for the calculation"""
         n_kpts = self.parse_scalar("n_kpts")
@@ -1050,7 +1056,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
 
         return int(n_kpts)
 
-    @lazyproperty
+    @cached_property
     def n_spins(self):
         """The number of spin channels for the chunk"""
         n_spins = self.parse_scalar("n_spins")
@@ -1060,7 +1066,7 @@ class AimsOutHeaderChunk(AimsOutChunk):
                 "channels in the header.")
         return int(n_spins)
 
-    @lazyproperty
+    @cached_property
     def electronic_temperature(self):
         """The electronic temperature for the chunk"""
         line_start = self.reverse_search_for(
@@ -1072,17 +1078,17 @@ class AimsOutHeaderChunk(AimsOutChunk):
         line = self.lines[line_start]
         return float(line.split("=")[-1].strip().split()[0])
 
-    @lazyproperty
+    @property
     def k_points(self):
         """All k-points listed in the calculation"""
-        return self._parse_k_points()["k_points"]
+        return self._k_points["k_points"]
 
-    @lazyproperty
+    @property
     def k_point_weights(self):
         """The k-point weights for the calculation"""
-        return self._parse_k_points()["k_point_weights"]
+        return self._k_points["k_point_weights"]
 
-    @lazyproperty
+    @cached_property
     def header_summary(self):
         """Dictionary summarizing the information inside the header"""
         return {
@@ -1118,8 +1124,8 @@ class AimsOutCalcChunk(AimsOutChunk):
         super().__init__(lines)
         self._header = header.header_summary
 
-    @lazymethod
-    def _parse_atoms(self):
+    @cached_property
+    def _atoms(self):
         """Create an atoms object for the subsequent structures
         calculated in the aims.out file"""
         start_keys = [
@@ -1174,7 +1180,7 @@ class AimsOutCalcChunk(AimsOutChunk):
 
         return atoms
 
-    @lazyproperty
+    @cached_property
     def forces(self):
         """Parse the forces from the aims.out file"""
         line_start = self.reverse_search_for(["Total atomic forces"])
@@ -1190,7 +1196,7 @@ class AimsOutCalcChunk(AimsOutChunk):
             ]
         )
 
-    @lazyproperty
+    @cached_property
     def stresses(self):
         """Parse the stresses from the aims.out file"""
         line_start = self.reverse_search_for(
@@ -1206,7 +1212,7 @@ class AimsOutCalcChunk(AimsOutChunk):
 
         return np.array(stresses)
 
-    @lazyproperty
+    @cached_property
     def stress(self):
         """Parse the stress from the aims.out file"""
         from ase.stress import full_3x3_to_voigt_6_stress
@@ -1227,7 +1233,7 @@ class AimsOutCalcChunk(AimsOutChunk):
         ]
         return full_3x3_to_voigt_6_stress(stress)
 
-    @lazyproperty
+    @cached_property
     def is_metallic(self):
         """Checks the outputfile to see if the chunk corresponds
         to a metallic system"""
@@ -1236,12 +1242,10 @@ class AimsOutCalcChunk(AimsOutChunk):
              "broadening function (occupation_type)"])
         return line_start != LINE_NOT_FOUND
 
-    @lazyproperty
-    def energy(self):
+    @cached_property
+    def total_energy(self):
         """Parse the energy from the aims.out file"""
-        atoms = self._parse_atoms()
-
-        if np.all(atoms.pbc) and self.is_metallic:
+        if np.all(self._atoms.pbc) and self.is_metallic:
             line_ind = self.reverse_search_for(["Total energy corrected"])
         else:
             line_ind = self.reverse_search_for(["Total energy uncorrected"])
@@ -1250,7 +1254,7 @@ class AimsOutCalcChunk(AimsOutChunk):
 
         return float(self.lines[line_ind].split()[5])
 
-    @lazyproperty
+    @cached_property
     def dipole(self):
         """Parse the electric dipole moment from the aims.out file."""
         line_start = self.reverse_search_for(["Total dipole moment [eAng]"])
@@ -1260,10 +1264,13 @@ class AimsOutCalcChunk(AimsOutChunk):
         line = self.lines[line_start]
         return np.array([float(inp) for inp in line.split()[6:9]])
 
-    @lazyproperty
+    @cached_property
     def dielectric_tensor(self):
         """Parse the dielectric tensor from the aims.out file"""
-        line_start = self.reverse_search_for(["PARSE DFPT_dielectric_tensor"])
+        line_start = self.reverse_search_for(
+            ["DFPT for dielectric_constant:--->",
+             "PARSE DFPT_dielectric_tensor"],
+        )
         if line_start == LINE_NOT_FOUND:
             return None
 
@@ -1273,7 +1280,7 @@ class AimsOutCalcChunk(AimsOutChunk):
         # make ndarray and return
         return np.array([np.fromstring(line, sep=' ') for line in lines])
 
-    @lazyproperty
+    @cached_property
     def polarization(self):
         """ Parse the polarization vector from the aims.out file"""
         line_start = self.reverse_search_for(["| Cartesian Polarization"])
@@ -1282,12 +1289,10 @@ class AimsOutCalcChunk(AimsOutChunk):
         line = self.lines[line_start]
         return np.array([float(s) for s in line.split()[-3:]])
 
-    @lazymethod
-    def _parse_hirshfeld(self):
+    @cached_property
+    def _hirshfeld(self):
         """Parse the Hirshfled charges volumes, and dipole moments from the
         ouput"""
-        atoms = self._parse_atoms()
-
         line_start = self.reverse_search_for(
             ["Performing Hirshfeld analysis of fragment charges and moments."]
         )
@@ -1318,9 +1323,10 @@ class AimsOutCalcChunk(AimsOutChunk):
             ]
         )
 
-        if not np.any(atoms.pbc):
+        if not np.any(self._atoms.pbc):
+            positions = self._atoms.get_positions()
             hirshfeld_dipole = np.sum(
-                hirshfeld_charges.reshape((-1, 1)) * atoms.get_positions(),
+                hirshfeld_charges.reshape((-1, 1)) * positions,
                 axis=1,
             )
         else:
@@ -1332,15 +1338,13 @@ class AimsOutCalcChunk(AimsOutChunk):
             "dipole": hirshfeld_dipole,
         }
 
-    @lazymethod
-    def _parse_eigenvalues(self):
+    @cached_property
+    def _eigenvalues(self):
         """Parse the eigenvalues and occupancies of the system. If eigenvalue
         for a particular k-point is not present in the output file
         then set it to np.nan
         """
 
-        atoms = self._parse_atoms()
-
         line_start = self.reverse_search_for(["Writing Kohn-Sham eigenvalues."])
         if line_start == LINE_NOT_FOUND:
             return {"eigenvalues": None, "occupancies": None}
@@ -1364,7 +1368,7 @@ class AimsOutCalcChunk(AimsOutChunk):
         else:
             line_end = min(line_end_1, line_end_2)
 
-        n_kpts = self.n_k_points if np.all(atoms.pbc) else 1
+        n_kpts = self.n_k_points if np.all(self._atoms.pbc) else 1
         if n_kpts is None:
             return {"eigenvalues": None, "occupancies": None}
 
@@ -1401,7 +1405,7 @@ class AimsOutCalcChunk(AimsOutChunk):
                 self.lines[occ_start + 1:occ_start + self.n_bands + 1]
             ):
                 if "***" in line:
-                    warn_msg = f"The {ll+1}th eigenvalue for the "
+                    warn_msg = f"The {ll + 1}th eigenvalue for the "
                     "{kpt_ind+1}th k-point and {spin}th channels could "
                     "not be read (likely too large to be printed "
                     "in the output file)"
@@ -1412,15 +1416,15 @@ class AimsOutCalcChunk(AimsOutChunk):
                 occupancies[kpt_ind, ll, spin] = float(split_line[1])
         return {"eigenvalues": eigenvalues, "occupancies": occupancies}
 
-    @lazyproperty
+    @cached_property
     def atoms(self):
         """Convert AimsOutChunk to Atoms object and add all non-standard
 outputs to atoms.info"""
-        atoms = self._parse_atoms()
+        atoms = self._atoms
 
         atoms.calc = SinglePointDFTCalculator(
             atoms,
-            energy=self.energy,
+            energy=self.free_energy,
             free_energy=self.free_energy,
             forces=self.forces,
             stress=self.stress,
@@ -1436,8 +1440,9 @@ outputs to atoms.info"""
     def results(self):
         """Convert an AimsOutChunk to a Results Dictionary"""
         results = {
-            "energy": self.energy,
+            "energy": self.free_energy,
             "free_energy": self.free_energy,
+            "total_energy": self.total_energy,
             "forces": self.forces,
             "stress": self.stress,
             "stresses": self.stresses,
@@ -1459,122 +1464,119 @@ outputs to atoms.info"""
             key: value for key,
             value in results.items() if value is not None}
 
-    # Properties from the aims.out header
-    @lazyproperty
+    @property
     def initial_atoms(self):
         """The initial structure defined in the geoemtry.in file"""
         return self._header["initial_atoms"]
 
-    @lazyproperty
+    @property
     def initial_cell(self):
         """The initial lattice vectors defined in the geoemtry.in file"""
         return self._header["initial_cell"]
 
-    @lazyproperty
+    @property
     def constraints(self):
         """The relaxation constraints for the calculation"""
         return self._header["constraints"]
 
-    @lazyproperty
+    @property
     def n_atoms(self):
         """The number of atoms for the material"""
         return self._header["n_atoms"]
 
-    @lazyproperty
+    @property
     def n_bands(self):
         """The number of Kohn-Sham states for the chunk"""
         return self._header["n_bands"]
 
-    @lazyproperty
+    @property
     def n_electrons(self):
         """The number of electrons for the chunk"""
         return self._header["n_electrons"]
 
-    @lazyproperty
+    @property
     def n_spins(self):
         """The number of spin channels for the chunk"""
         return self._header["n_spins"]
 
-    @lazyproperty
+    @property
     def electronic_temperature(self):
         """The electronic temperature for the chunk"""
         return self._header["electronic_temperature"]
 
-    @lazyproperty
+    @property
     def n_k_points(self):
         """The number of electrons for the chunk"""
         return self._header["n_k_points"]
 
-    @lazyproperty
+    @property
     def k_points(self):
         """The number of spin channels for the chunk"""
         return self._header["k_points"]
 
-    @lazyproperty
+    @property
     def k_point_weights(self):
         """k_point_weights electronic temperature for the chunk"""
         return self._header["k_point_weights"]
 
-    @lazyproperty
+    @cached_property
     def free_energy(self):
         """The free energy for the chunk"""
         return self.parse_scalar("free_energy")
 
-    @lazyproperty
+    @cached_property
     def n_iter(self):
         """The number of SCF iterations needed to converge the SCF cycle for
 the chunk"""
         return self.parse_scalar("number_of_iterations")
 
-    @lazyproperty
+    @cached_property
     def magmom(self):
         """The magnetic moment for the chunk"""
         return self.parse_scalar("magnetic_moment")
 
-    @lazyproperty
+    @cached_property
     def E_f(self):
         """The Fermi energy for the chunk"""
         return self.parse_scalar("fermi_energy")
 
-    @lazyproperty
+    @cached_property
     def converged(self):
         """True if the chunk is a fully converged final structure"""
         return (len(self.lines) > 0) and ("Have a nice day." in self.lines[-5:])
 
-    @lazyproperty
+    @property
     def hirshfeld_charges(self):
         """The Hirshfeld charges for the chunk"""
-        return self._parse_hirshfeld()["charges"]
+        return self._hirshfeld["charges"]
 
-    @lazyproperty
+    @property
     def hirshfeld_atomic_dipoles(self):
         """The Hirshfeld atomic dipole moments for the chunk"""
-        return self._parse_hirshfeld()["atomic_dipoles"]
+        return self._hirshfeld["atomic_dipoles"]
 
-    @lazyproperty
+    @property
     def hirshfeld_volumes(self):
         """The Hirshfeld volume for the chunk"""
-        return self._parse_hirshfeld()["volumes"]
+        return self._hirshfeld["volumes"]
 
-    @lazyproperty
+    @property
     def hirshfeld_dipole(self):
         """The Hirshfeld systematic dipole moment for the chunk"""
-        atoms = self._parse_atoms()
-
-        if not np.any(atoms.pbc):
-            return self._parse_hirshfeld()["dipole"]
+        if not np.any(self._atoms.pbc):
+            return self._hirshfeld["dipole"]
 
         return None
 
-    @lazyproperty
+    @property
     def eigenvalues(self):
         """All outputted eigenvalues for the system"""
-        return self._parse_eigenvalues()["eigenvalues"]
+        return self._eigenvalues["eigenvalues"]
 
-    @lazyproperty
+    @property
     def occupancies(self):
         """All outputted occupancies for the system"""
-        return self._parse_eigenvalues()["occupancies"]
+        return self._eigenvalues["occupancies"]
 
 
 def get_header_chunk(fd):
