@@ -1299,6 +1299,214 @@ dvscf_q2r = {
     ]
 }
 
+epw_keys = {
+    "inputepw": [
+        "adapt_ethrdg_plrn",
+        "a2f",
+        "amass",
+        "asr_typ",
+        "assume_metal",
+        "band_plot",
+        "bands_skipped",
+        "bfieldx",
+        "bfieldy",
+        "bfieldz",
+        "bnd_cum",
+        "broyden_beta",
+        "broyden_ndim",
+        "cal_psir_plrn",
+        "carrier",
+        "conv_thr_iaxis",
+        "conv_thr_plrn",
+        "conv_thr_racon",
+        "conv_thr_raxis",
+        "cumulant",
+        "degaussq",
+        "degaussw",
+        "delta_approx",
+        "delta_qsmear",
+        "delta_smear",
+        "dvscf_dir",
+        "do_CHBB",
+        "efermi_read",
+        "eig_read",
+        "elecselfen",
+        "eliashberg",
+        "elph",
+        "ep_coupling",
+        "epbwrite",
+        "epbread",
+        "epexst",
+        "ephwrite",
+        "epmatkqread",
+        "eps_acustic",
+        "epsiHEG",
+        "epwread",
+        "epwwrite",
+        "etf_mem",
+        "ethrdg_plrn",
+        "fermi_diff",
+        "fermi_energy",
+        "fermi_plot",
+        "fila2f",
+        "fildvscf",
+        "filkf",
+        "filqf",
+        "filukk",
+        "filukq",
+        "fixsym",
+        "fsthick",
+        "gap_edge",
+        "gb_scattering",
+        "gb_only",
+        "gb_size",
+        "imag_read",
+        "init_ethrdg_plrn",
+        "init_k0_plrn",
+        "init_ntau_plrn",
+        "init_plrn",
+        "init_sigma_plrn",
+        "interp_Ank_plrn",
+        "interp_Bqu_plrn",
+        "int_mob",
+        "io_lvl_plrn",
+        "iterative_bte",
+        "iverbosity",
+        "ii_g",
+        "ii_scattering",
+        "ii_only",
+        "ii_lscreen",
+        "ii_partion",
+        "ii_charge",
+        "ii_n",
+        "ii_eda",
+        "kerread",
+        "kerwrite",
+        "kmaps",
+        "lacon",
+        "laniso",
+        "lifc",
+        "limag",
+        "lindabs",
+        "liso",
+        "longrange",
+        "lpade",
+        "lphase",
+        "lpolar",
+        "lreal",
+        "lscreen",
+        "lunif",
+        "loptabs",
+        "len_mesh",
+        "max_memlt",
+        "meff",
+        "mob_maxiter",
+        "mp_mesh_k",
+        "mp_mesh_q",
+        "muc",
+        "meshnum",
+        "nbndsub",
+        "ncarrier",
+        "nc",
+        "nel",
+        "nest_fn",
+        "nethrdg_plrn",
+        "ngaussw",
+        "niter_plrn",
+        "nk1",
+        "nk2",
+        "nk3",
+        "nkf1",
+        "nkf2",
+        "nkf3",
+        "nq1",
+        "nq2",
+        "nq3",
+        "nqf1",
+        "nqf2",
+        "nqf3",
+        "npade",
+        "nqsmear",
+        "nqstep",
+        "n_r",
+        "nsiter",
+        "nsmear",
+        "nstemp",
+        "nswi",
+        "nswc",
+        "nswfc",
+        "nw",
+        "nw_specfun",
+        "nq_init",
+        "omegamax",
+        "omegamin",
+        "omegastep",
+        "phonselfen",
+        "plselfen",
+        "plrn",
+        "prefix",
+        "prtgkk",
+        "pwc",
+        "QD_bin",
+        "QD_min",
+        "rand_nq",
+        "rand_nk",
+        "rand_q",
+        "rand_k",
+        "restart",
+        "restart_filq",
+        "restart_plrn",
+        "restart_step",
+        "scell_mat",
+        "scell_mat_plrn",
+        "scr_typ",
+        "scatread",
+        "scattering",
+        "scattering_serta",
+        "scattering_0rta",
+        "scissor",
+        "selecqread",
+        "smear_rpa",
+        "specfun_el",
+        "specfun_ph",
+        "specfun_pl",
+        "system_2d",
+        "shortrange",
+        "step_wf_grid_plrn",
+        "start_mesh",
+        "temps",
+        "tc_linear",
+        "tc_linear_solver",
+        "type_plrn",
+        "vme",
+        "wannierize",
+        "wepexst",
+        "wmax",
+        "wmax_specfun",
+        "wmin",
+        "wmin_specfun",
+        "wscut",
+        "wsfc",
+        "auto_projections",
+        "dis_froz_min",
+        "dis_froz_max",
+        "iprint",
+        "num_iter",
+        "proj",
+        "reduce_unk",
+        "scdm_entanglement",
+        "scdm_mu",
+        "scdm_proj",
+        "scdm_sigma",
+        "wannier_plot",
+        "wannier_plot_list",
+        "wannier_plot_radius",
+        "wannier_plot_scale",
+        "wannier_plot_supercell",
+        "wdata"
+    ]
+}
+
 ALL_KEYS = {
     "pw": pw_keys,
     "ph": ph_keys,
@@ -1334,5 +1542,6 @@ ALL_KEYS = {
     "d3hess": d3hess_keys,
     "neb": neb_keys,
     "postahc": postahc_keys,
-    "dvscf_q2r": dvscf_q2r
+    "dvscf_q2r": dvscf_q2r,
+    "epw": epw_keys
 }
