@@ -24,8 +24,17 @@ import warnings
 from importlib import import_module
 from importlib.metadata import entry_points
 from pathlib import Path, PurePath
-from typing import (IO, Any, Dict, Iterable, List, Optional, Sequence, Tuple,
-                    Union)
+from typing import (
+    IO,
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+)
 
 from ase.atoms import Atoms
 from ase.parallel import parallel_function, parallel_generator
@@ -581,7 +590,7 @@ def open_with_compression(filename: str, mode: str = 'r') -> IO:
     elif mode == 'a':
         mode = 'at'
 
-    root, compression = get_compression(filename)
+    _root, compression = get_compression(filename)
 
     if compression == 'gz':
         import gzip
@@ -941,7 +950,7 @@ def filetype(
             return 'mysql'
 
         # strip any compression extensions that can be read
-        root, compression = get_compression(filename)
+        root, _compression = get_compression(filename)
         basename = os.path.basename(root)
 
         if '.' in basename:
