@@ -130,7 +130,7 @@ def read_magres(fd, include_unrecognised=False):
             tuples.
         """
 
-        name, records = block
+        _name, records = block
 
         # 3x3 tensor
         def ntensor33(name):
@@ -179,7 +179,7 @@ def read_magres(fd, include_unrecognised=False):
             Parse atoms block into data dictionary given list of record tuples.
         """
 
-        name, records = block
+        _name, records = block
 
         # Lattice record: a1, a2 a3, b1, b2, b3, c1, c2 c3
         def lattice(d):
@@ -216,7 +216,7 @@ def read_magres(fd, include_unrecognised=False):
             tuples.
         """
 
-        name, records = block
+        _name, records = block
 
         data_dict = {}
 
