@@ -25,6 +25,27 @@ __all__ = [
 ]
 
 
+def parse_poscar_scaling_factor(line: str) -> np.ndarray:
+    """Parse scaling factor(s) in the second line in POSCAR/CONTCAR.
+
+    This can also be one negative number or three positive numbers.
+
+    https://www.vasp.at/wiki/index.php/POSCAR#Full_format_specification
+
+    """
+    scale = []
+    for _ in line.split()[:3]:
+        try:
+            scale.append(float(_))
+        except ValueError:
+            break
+    if len(scale) not in {1, 3}:
+        raise RuntimeError('The number of scaling factors must be 1 or 3.')
+    if len(scale) == 3 and any(_ < 0.0 for _ in scale):
+        raise RuntimeError('All three scaling factors must be positive.')
+    return np.array(scale)
+
+
 def get_atomtypes(fname):
     """Given a file name, get the atomic symbols.
 
@@ -139,21 +160,14 @@ def read_vasp(filename='CONTCAR'):
     # file.
     line1 = fd.readline()
 
-    # Scaling factor
-    # This can also be one negative number or three positive numbers.
-    # https://www.vasp.at/wiki/index.php/POSCAR#Full_format_specification
-    scale = np.array(fd.readline().split()[:3], dtype=float)
-    if len(scale) not in [1, 3]:
-        raise RuntimeError('The number of scaling factors must be 1 or 3.')
-    if len(scale) == 3 and np.any(scale < 0.0):
-        raise RuntimeError('All three scaling factors must be positive.')
+    scale = parse_poscar_scaling_factor(fd.readline())
 
     # Now the lattice vectors
     cell = np.array([fd.readline().split()[:3] for _ in range(3)], dtype=float)
     # Negative scaling factor corresponds to the cell volume.
     if scale[0] < 0.0:
         scale = np.cbrt(-1.0 * scale / np.linalg.det(cell))
-    cell *= scale
+    cell *= scale  # This works for both one and three scaling factors.
 
     # Number of atoms. Again this must be in the same order as
     # in the first line
@@ -391,9 +405,10 @@ def read_vasp_xml(filename='vasprun.xml', index=-1):
     import xml.etree.ElementTree as ET
     from collections import OrderedDict
 
-    from ase.calculators.singlepoint import (SinglePointDFTCalculator,
-                                             SinglePointKPoint)
-    from ase.constraints import FixAtoms, FixScaled
+    from ase.calculators.singlepoint import (
+        SinglePointDFTCalculator,
+        SinglePointKPoint,
+    )
     from ase.units import GPa
 
     tree = ET.iterparse(filename, events=['start', 'end'])
@@ -466,7 +481,7 @@ def read_vasp_xml(filename='vasprun.xml', index=-1):
                         if flags.all():
                             fixed_indices.append(i)
                         elif flags.any():
-                            constraints.append(FixScaled(cell_init, i, flags))
+                            constraints.append(FixScaled(i, flags, cell_init))
 
                     if fixed_indices:
                         constraints.append(FixAtoms(fixed_indices))
