@@ -1176,37 +1176,43 @@ def identify_lattice(cell, eps=2e-4, *, pbc=True):
                 op = normalization_op @ np.linalg.inv(reduction_op)
                 matching_lattices.append((lat, op))
 
-        # Among any matching lattices, return the one with lowest
-        # orthogonality defect:
-        best = None
-        best_defect = np.inf
-        for lat, op in matching_lattices:
-            cell = lat.tocell()
-            lengths = cell.lengths()[pbc]
-            generalized_volume = cell.complete().volume
-            defect = np.prod(lengths) / generalized_volume
-            if defect < best_defect:
-                best = lat, op
-                best_defect = defect
+        if not matching_lattices:
+            continue  # Move to next Bravais lattice
 
-        if best is not None:
-            if npbc == 2:
-                # The 3x3 operation may flip the z axis, but then the x/y
-                # components are necessarily also left-handed which
-                # means a defacto left-handed 2D bandpath.
-                #
-                # We repair this by applying an operation that unflips the
-                # z axis and interchanges x/y:
-                if op[2, 2] < 0:
-                    repair_op = np.array([[0, 1, 0], [1, 0, 0], [0, 0, -1]])
-                    op = repair_op @ op
-                    best = lat, op
+        lat, op = pick_best_lattice(matching_lattices)
 
-            return best
+        if npbc == 2 and op[2, 2] < 0:
+            op = flip_2d_handedness(op)
+
+        return lat, op
 
     raise RuntimeError('Failed to recognize lattice')
 
 
+def flip_2d_handedness(op):
+    # The 3x3 operation may flip the z axis, but then the x/y
+    # components are necessarily also left-handed which
+    # means a defacto left-handed 2D bandpath.
+    #
+    # We repair this by applying an operation that unflips the
+    # z axis and interchanges x/y:
+    repair_op = np.array([[0, 1, 0], [1, 0, 0], [0, 0, -1]])
+    return repair_op @ op
+
+
+def pick_best_lattice(matching_lattices):
+    """Return (lat, op) with lowest orthogonality defect."""
+    best = None
+    best_defect = np.inf
+    for lat, op in matching_lattices:
+        cell = lat.tocell().complete()
+        orthogonality_defect = np.prod(cell.lengths()) / cell.volume
+        if orthogonality_defect < best_defect:
+            best = lat, op
+            best_defect = orthogonality_defect
+    return best
+
+
 class LatticeChecker:
     # The check order is slightly different than elsewhere listed order
     # as we need to check HEX/RHL before the ORCx family.
