@@ -1,8 +1,9 @@
 """Molecular Dynamics."""
 
 from ase.md.andersen import Andersen
+from ase.md.bussi import Bussi
 from ase.md.langevin import Langevin
 from ase.md.logger import MDLogger
 from ase.md.verlet import VelocityVerlet
 
-__all__ = ['MDLogger', 'VelocityVerlet', 'Langevin', 'Andersen']
+__all__ = ['MDLogger', 'VelocityVerlet', 'Langevin', 'Andersen', 'Bussi']
