@@ -7,11 +7,14 @@ This module only depends on NumPy and the space group database.
 
 import os
 import warnings
-from functools import total_ordering
+from functools import lru_cache, total_ordering
+from types import SimpleNamespace
 from typing import Union
 
 import numpy as np
 
+from ase.utils import deprecated
+
 __all__ = ['Spacegroup']
 
 
@@ -56,55 +59,86 @@ class Spacegroup:
            [ 0.5,  0. ,  0.5],
            [ 0.5,  0.5,  0. ]])
     """
-    no = property(
-        lambda self: self._no,
-        doc='Space group number in International Tables of Crystallography.')
-    symbol = property(
-        lambda self: self._symbol,
-        doc='Hermann-Mauguin (or international) symbol for the space group.')
-    setting = property(lambda self: self._setting,
-                       doc='Space group setting. Either one or two.')
-    lattice = property(lambda self: self._symbol[0],
-                       doc="""Lattice type:
+    @property
+    def no(self):
+        """Space group number in International Tables of Crystallography."""
+        return self._no
 
-    P     primitive
-    I     body centering, h+k+l=2n
-    F     face centering, h,k,l all odd or even
-    A,B,C single face centering, k+l=2n, h+l=2n, h+k=2n
-    R     rhombohedral centering, -h+k+l=3n (obverse); h-k+l=3n (reverse)
-            """)
-    centrosymmetric = property(lambda self: self._centrosymmetric,
-                               doc='Whether a center of symmetry exists.')
-    scaled_primitive_cell = property(
-        lambda self: self._scaled_primitive_cell,
-        doc='Primitive cell in scaled coordinates as a matrix with the '
-        'primitive vectors along the rows.')
-    reciprocal_cell = property(
-        lambda self: self._reciprocal_cell,
-        doc='Tree Miller indices that span all kinematically non-forbidden '
-        'reflections as a matrix with the Miller indices along the rows.')
-    nsubtrans = property(lambda self: len(self._subtrans),
-                         doc='Number of cell-subtranslation vectors.')
+    @property
+    def symbol(self):
+        """Hermann-Mauguin (or international) symbol for the space group."""
+        return self._symbol
 
-    def _get_nsymop(self):
-        """Returns total number of symmetry operations."""
-        if self.centrosymmetric:
-            return 2 * len(self._rotations) * len(self._subtrans)
-        else:
-            return len(self._rotations) * len(self._subtrans)
+    @property
+    def setting(self):
+        """Space group setting. Either one or two."""
+        return self._setting
 
-    nsymop = property(_get_nsymop, doc='Total number of symmetry operations.')
-    subtrans = property(
-        lambda self: self._subtrans,
-        doc='Translations vectors belonging to cell-sub-translations.')
-    rotations = property(
-        lambda self: self._rotations,
-        doc='Symmetry rotation matrices. The invertions are not included '
-        'for centrosymmetrical crystals.')
-    translations = property(
-        lambda self: self._translations,
-        doc='Symmetry translations. The invertions are not included '
-        'for centrosymmetrical crystals.')
+    @property
+    def lattice(self):
+        """Lattice type.
+
+        P     primitive
+        I     body centering, h+k+l=2n
+        F     face centering, h,k,l all odd or even
+        A,B,C single face centering, k+l=2n, h+l=2n, h+k=2n
+        R     rhombohedral centering, -h+k+l=3n (obverse); h-k+l=3n (reverse)
+        """
+        return self._symbol[0]
+
+    @property
+    def centrosymmetric(self):
+        """Whether a center of symmetry exists."""
+        return self._centrosymmetric
+
+    @property
+    def scaled_primitive_cell(self):
+        """Primitive cell in scaled coordinates.
+
+        Matrix with the primitive vectors along the rows.
+        """
+        return self._scaled_primitive_cell
+
+    @property
+    def reciprocal_cell(self):
+        """
+
+        Tree Miller indices that span all kinematically non-forbidden
+        reflections as a matrix with the Miller indices along the rows.
+        """
+        return self._reciprocal_cell
+
+    @property
+    def nsubtrans(self):
+        """Number of cell-subtranslation vectors."""
+        return len(self._subtrans)
+
+    @property
+    def nsymop(self):
+        """Total number of symmetry operations."""
+        scale = 2 if self.centrosymmetric else 1
+        return scale * len(self._rotations) * len(self._subtrans)
+
+    @property
+    def subtrans(self):
+        """Translations vectors belonging to cell-sub-translations."""
+        return self._subtrans
+
+    @property
+    def rotations(self):
+        """Symmetry rotation matrices.
+
+        The invertions are not included for centrosymmetrical crystals.
+        """
+        return self._rotations
+
+    @property
+    def translations(self):
+        """Symmetry translations.
+
+        The invertions are not included for centrosymmetrical crystals.
+        """
+        return self._translations
 
     def __init__(self, spacegroup: _SPACEGROUP, setting=1, datafile=None):
         """Returns a new Spacegroup instance.
@@ -128,8 +162,16 @@ class Spacegroup:
             return
         if not datafile:
             datafile = get_datafile()
-        with open(datafile) as fd:
-            _read_datafile(self, spacegroup, setting, fd)
+        namespace = _read_datafile(spacegroup, setting, datafile)
+        self._no = namespace._no
+        self._symbol = namespace._symbol
+        self._setting = namespace._setting
+        self._centrosymmetric = namespace._centrosymmetric
+        self._scaled_primitive_cell = namespace._scaled_primitive_cell
+        self._reciprocal_cell = namespace._reciprocal_cell
+        self._subtrans = namespace._subtrans
+        self._rotations = namespace._rotations
+        self._translations = namespace._translations
 
     def __repr__(self):
         return 'Spacegroup(%d, setting=%d)' % (self.no, self.setting)
@@ -401,48 +443,57 @@ class Spacegroup:
         >>> kinds
         [0, 0, 0, 0, 1, 1, 1, 1]
         """
-        kinds = []
-        sites = []
+        if onduplicates not in ('keep', 'replace', 'warn', 'error'):
+            raise SpacegroupValueError(
+                'Argument "onduplicates" must be one of: '
+                '"keep", "replace", "warn" or "error".'
+            )
 
         scaled = np.array(scaled_positions, ndmin=2)
+        rotations, translations = zip(*self.get_symop())
+        rotations = np.array(rotations)
+        translations = np.array(translations)
 
+        def find_orbit(point: np.ndarray) -> np.ndarray:
+            """Find crystallographic orbit of the given point."""
+            candidates = ((rotations @ point) + translations % 1.0) % 1.0
+            orbit = [candidates[0]]
+            for member in candidates[1:]:
+                diff = member - orbit
+                diff -= np.rint(diff)
+                if not np.any(np.all(np.abs(diff) < symprec, axis=1)):
+                    orbit.append(member)
+            return np.array(orbit)
+
+        orbits = []
         for kind, pos in enumerate(scaled):
-            for rot, trans in self.get_symop():
-                site = np.mod(np.dot(rot, pos) + trans, 1.)
-                if not sites:
-                    sites.append(site)
-                    kinds.append(kind)
-                    continue
-                t = site - sites
-                mask = np.all(
-                    (abs(t) < symprec) | (abs(abs(t) - 1.0) < symprec), axis=1)
-                if np.any(mask):
-                    inds = np.argwhere(mask).flatten()
-                    for ind in inds:
-                        # then we would just add the same thing again -> skip
-                        if kinds[ind] == kind:
-                            pass
-                        elif onduplicates == 'keep':
-                            pass
-                        elif onduplicates == 'replace':
-                            kinds[ind] = kind
-                        elif onduplicates == 'warn':
-                            warnings.warn('scaled_positions %d and %d '
-                                          'are equivalent' %
-                                          (kinds[ind], kind))
-                        elif onduplicates == 'error':
-                            raise SpacegroupValueError(
-                                'scaled_positions %d and %d are equivalent' %
-                                (kinds[ind], kind))
-                        else:
-                            raise SpacegroupValueError(
-                                'Argument "onduplicates" must be one of: '
-                                '"keep", "replace", "warn" or "error".')
-                else:
-                    sites.append(site)
-                    kinds.append(kind)
+            for i, (kind0, positions0) in enumerate(orbits):
+                diff = pos - positions0
+                diff -= np.rint(diff)
+                if np.any(np.all(np.abs(diff) < symprec, axis=1)):
+                    if onduplicates == 'keep':
+                        pass
+                    elif onduplicates == 'replace':
+                        orbits[i] = (kind, positions0)
+                    elif onduplicates == 'warn':
+                        warnings.warn(
+                            'scaled_positions %d and %d are equivalent' %
+                            (kind0, kind))
+                    elif onduplicates == 'error':
+                        raise SpacegroupValueError(
+                            'scaled_positions %d and %d are equivalent' %
+                            (kind0, kind))
+                    break
+            else:
+                orbits.append((kind, find_orbit(pos)))
 
-        return np.array(sites), kinds
+        kinds = []
+        sites = []
+        for kind, orbit in orbits:
+            kinds.extend(len(orbit) * [kind])
+            sites.append(orbit)
+
+        return np.concatenate(sites, axis=0), kinds
 
     def symmetry_normalised_sites(self,
                                   scaled_positions,
@@ -640,11 +691,11 @@ def _read_datafile_entry(spg, no, symbol, setting, f):
                                      for i in range(3)],
                                     dtype=int)
     # subtranslations
-    spg._nsubtrans = int(f.readline().split()[0])
+    nsubtrans = int(f.readline().split()[0])
     spg._subtrans = np.array(
         [
             [float(floats.get(t, t)) for t in f.readline().split()]
-            for _ in range(spg._nsubtrans)
+            for _ in range(nsubtrans)
         ],
         dtype=float,
     )
@@ -657,12 +708,17 @@ def _read_datafile_entry(spg, no, symbol, setting, f):
         ],
         dtype=float,
     )
-    spg._nsymop = nsym
     spg._rotations = np.array(symop[:, :9].reshape((nsym, 3, 3)), dtype=int)
     spg._translations = symop[:, 9:]
 
 
-def _read_datafile(spg, spacegroup, setting, f):
+@lru_cache
+def _read_datafile(spacegroup, setting, datafile):
+    with open(datafile, encoding='utf-8') as fd:
+        return _read_f(spacegroup, setting, fd)
+
+
+def _read_f(spacegroup, setting, f):
     if isinstance(spacegroup, int):
         pass
     elif isinstance(spacegroup, str):
@@ -686,8 +742,9 @@ def _read_datafile(spg, spacegroup, setting, f):
             (setting is None or _setting == setting))
 
         if condition:
-            _read_datafile_entry(spg, _no, _symbol, _setting, f)
-            break
+            namespace = SimpleNamespace()
+            _read_datafile_entry(namespace, _no, _symbol, _setting, f)
+            return namespace
         else:
             _skip_to_blank(f, spacegroup, setting)
 
@@ -889,7 +946,6 @@ def spacegroup_from_data(no=None,
         spg._reciprocal_cell = np.array(reciprocal_cell)
     if subtrans is not None:
         spg._subtrans = np.atleast_2d(subtrans)
-        spg._nsubtrans = spg._subtrans.shape[0]
     if sitesym is not None:
         spg._rotations, spg._translations = parse_sitesym(sitesym)
         have_sym = True
@@ -903,15 +959,31 @@ def spacegroup_from_data(no=None,
         if spg._rotations.shape[0] != spg._translations.shape[0]:
             raise SpacegroupValueError('inconsistent number of rotations and '
                                        'translations')
-        spg._nsymop = spg._rotations.shape[0]
     return spg
 
 
+@deprecated(
+    '`get_spacegroup` has been deprecated due to its misleading output. '
+    'The returned `Spacegroup` object has symmetry operations for a '
+    'standard setting regardress of the given `Atoms` object. '
+    'See https://gitlab.com/ase/ase/-/issues/1534 for details. '
+    'Please use `ase.spacegroup.symmetrize.check_symmetry` or `spglib` '
+    'directly to get the symmetry operations for the given `Atoms` object.'
+)
 def get_spacegroup(atoms, symprec=1e-5):
     """Determine the spacegroup to which belongs the Atoms object.
 
     This requires spglib: https://atztogo.github.io/spglib/ .
 
+    .. warning::
+        The returned ``Spacegroup`` object has symmetry operations for a
+        standard setting regardless of the given ``Atoms`` object.
+        See https://gitlab.com/ase/ase/-/issues/1534 for details.
+
+    .. deprecated:: 3.24.0
+        Please use ``ase.spacegroup.symmetrize.check_symmetry`` or ``spglib``
+        directly to get the symmetry operations for the given ``Atoms`` object.
+
     Parameters:
 
     atoms: Atoms object
