@@ -1,17 +1,23 @@
 import collections
 from functools import reduce, singledispatch
-from typing import (Any, Dict, Iterable, List, Optional, Sequence, TypeVar,
-                    Union, overload)
+from typing import (
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Sequence,
+    TypeVar,
+    Union,
+    overload,
+)
 
 import numpy as np
+from matplotlib.axes import Axes
 
 from ase.spectrum.dosdata import DOSData, Floats, GridDOSData, Info, RawDOSData
 from ase.utils.plotting import SimplePlottingAxes
 
-# This import is for the benefit of type-checking / mypy
-if False:
-    import matplotlib.axes
-
 
 class DOSCollection(collections.abc.Sequence):
     """Base class for a collection of DOSData objects"""
@@ -53,10 +59,10 @@ class DOSCollection(collections.abc.Sequence):
              xmax: float = None,
              width: float = 0.1,
              smearing: str = 'Gauss',
-             ax: 'matplotlib.axes.Axes' = None,
+             ax: Axes = None,
              show: bool = False,
              filename: str = None,
-             mplargs: dict = None) -> 'matplotlib.axes.Axes':
+             mplargs: dict = None) -> Axes:
         """Simple plot of collected DOS data, resampled onto a grid
 
         If the special key 'label' is present in self.info, this will be set
@@ -536,10 +542,10 @@ class GridDOSCollection(DOSCollection):
              xmax: float = None,
              width: float = None,
              smearing: str = 'Gauss',
-             ax: 'matplotlib.axes.Axes' = None,
+             ax: Axes = None,
              show: bool = False,
              filename: str = None,
-             mplargs: dict = None) -> 'matplotlib.axes.Axes':
+             mplargs: dict = None) -> Axes:
         """Simple plot of collected DOS data, resampled onto a grid
 
         If the special key 'label' is present in self.info, this will be set
@@ -589,7 +595,7 @@ class GridDOSCollection(DOSCollection):
         return ax
 
     @staticmethod
-    def _plot_broadened(ax: 'matplotlib.axes.Axes',
+    def _plot_broadened(ax: Axes,
                         energies: Floats,
                         all_y: np.ndarray,
                         all_labels: Sequence[str],
