@@ -13,18 +13,18 @@ def atoms():
 
 def test_set_calculator(atoms):
     calc = EMT()
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         atoms.set_calculator(calc)
     assert atoms.calc is calc
 
 
 def test_get_calculator(atoms):
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         assert atoms.get_calculator() is None
 
 
 def test_del_calculator(atoms):
     atoms.calc = EMT()
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         del atoms.calc
     assert atoms.calc is None
