@@ -15,14 +15,17 @@ def test_bandstructure(testdir, plt):
                                kpts={'path': path, 'npoints': 200})
     atoms.get_potential_energy()
     bs = atoms.calc.band_structure()
-    coords, labelcoords, labels = bs.get_labels()
+    _coords, _labelcoords, labels = bs.get_labels()
     print(labels)
     bs.write('hmm.json')
     bs = BandStructure.read('hmm.json')
-    coords, labelcoords, labels = bs.get_labels()
+    _coords, _labelcoords, labels = bs.get_labels()
     print(labels)
     assert ''.join(labels) == 'GXWKGLUWLKUX'
     bs.plot(emax=10, filename='bs.png')
+    cols = np.linspace(-1.0, 1.0, bs.energies.size)
+    cols.shape = bs.energies.shape
+    bs.plot(emax=10, point_colors=cols, filename='bs2.png')
 
 
 @pytest.fixture()
