@@ -1,8 +1,11 @@
 import numpy as np
 import pytest
 
-from ase.lattice import (all_variants, bravais_lattices,
-                         get_lattice_from_canonical_cell)
+from ase.lattice import (
+    all_variants,
+    bravais_lattices,
+    get_lattice_from_canonical_cell,
+)
 
 
 @pytest.mark.parametrize('name', list(bravais_lattices))
