@@ -2,6 +2,7 @@ import pytest
 from numpy.testing import assert_allclose
 
 from ase.build import molecule
+from ase.calculators.fd import calculate_numerical_forces
 
 
 @pytest.mark.skip(reason='we do not know how to compile psi4')
@@ -30,5 +31,5 @@ def test_main(factory):
                     rtol=1e-4, atol=1e-4)
 
     # Compare analytical vs numerical forces
-    assert_allclose(atoms.get_forces(), calc.calculate_numerical_forces(atoms),
+    assert_allclose(atoms.get_forces(), calculate_numerical_forces(atoms),
                     rtol=1e-4, atol=1e-4)
