@@ -2,9 +2,11 @@ import numpy as np
 import pytest
 
 from ase import Atoms
-from ase.calculators.bond_polarizability import (BondPolarizability,
-                                                 Linearized,
-                                                 LippincottStuttman)
+from ase.calculators.bond_polarizability import (
+    BondPolarizability,
+    Linearized,
+    LippincottStuttman,
+)
 
 
 def test_CC_bond():
