@@ -16,21 +16,21 @@ def test_eam_run(factory):
     assert abs(6.36379627645 - np.linalg.norm(slab.get_forces())) < 1E-8
 
 
+@pytest.mark.parametrize('with_elements', (False, True))
 @pytest.mark.parametrize(
-    'potential,element',
-    (
-        ('Pt_u3.eam', 'Pt'),
-        ('NiAlH_jea.eam.alloy', 'Ni'),
-        ('NiAlH_jea.eam.fs', 'Ni'),
-        ('AlCu.adp', 'Al'),
-    )
+    'potential',
+    ('Pt_u3.eam', 'NiAlH_jea.eam.alloy', 'NiAlH_jea.eam.fs', 'AlCu.adp'),
 )
 @pytest.mark.calculator('eam')
 @pytest.mark.calculator_lite()
-def test_read_potential(factory, potential: str, element: str):
+def test_read_potential(factory, potential: str, with_elements: bool):
     """Test if the potential can be read without errors."""
+    element = potential[:2]
     potential = f'{factory.factory.potentials_path}/{potential}'
-    calc = factory.calc(potential=potential, elements=[element])
+    if with_elements:
+        calc = factory.calc(potential=potential, elements=[element])
+    else:
+        calc = factory.calc(potential=potential)
     atoms = bulk(element)
     atoms.calc = calc
     atoms.get_potential_energy()
