@@ -2,8 +2,12 @@ import pytest
 
 from ase.build import molecule
 from ase.calculators.emt import EMT
-from ase.constraints import (ExternalForce, FixBondLength, MirrorForce,
-                             MirrorTorque)
+from ase.constraints import (
+    ExternalForce,
+    FixBondLength,
+    MirrorForce,
+    MirrorTorque,
+)
 from ase.optimize import FIRE
 
 
