@@ -1,8 +1,7 @@
 import numpy as np
 
 from ase.build import fcc111
-from ase.ga.particle_mutations import (Poor2richPermutation,
-                                       Rich2poorPermutation)
+from ase.ga.particle_mutations import Poor2richPermutation, Rich2poorPermutation
 
 
 def test_rich2poor_permutations():
