@@ -2,8 +2,7 @@ from ase import units
 from ase.build import bulk
 from ase.calculators.emt import EMT
 from ase.md.langevin import Langevin
-from ase.md.velocitydistribution import (MaxwellBoltzmannDistribution,
-                                         Stationary)
+from ase.md.velocitydistribution import MaxwellBoltzmannDistribution, Stationary
 
 
 def test_langevin_asapcompat():
