@@ -16,4 +16,4 @@ def test_neighborlist_initialization():
         nl.get_connectivity_matrix()
 
     nl.update(atoms)
-    indices, offsets = nl.get_neighbors(0)
+    nl.get_neighbors(0)
