@@ -7,7 +7,6 @@ from ase.calculators.emt import EMT
 from ase.constraints import FixAtoms
 from ase.io import read
 from ase.optimize import QuasiNewton
-from ase.visualize import view
 
 
 @pytest.mark.optimize()
@@ -24,9 +23,6 @@ def test_replay(testdir):
     h0 = 2.0
     a += Atom('Ag', (d / 2, d / 2, h0))
 
-    if 0:
-        view(a)
-
     constraint = FixAtoms(range(len(a) - 1))
     a.calc = EMT()
     a.set_constraint(constraint)
