@@ -3,8 +3,13 @@ from numpy import linalg
 
 from ase.transport.greenfunction import GreenFunction
 from ase.transport.selfenergy import BoxProbe, LeadSelfEnergy
-from ase.transport.tools import (cutcoupling, dagger, fermidistribution,
-                                 rotate_matrix, subdiagonalize)
+from ase.transport.tools import (
+    cutcoupling,
+    dagger,
+    fermidistribution,
+    rotate_matrix,
+    subdiagonalize,
+)
 from ase.units import kB
 
 
