@@ -1,22 +1,22 @@
-# This import is for the benefit of type-checking / mypy
-if False:
-    import matplotlib.axes
-    import matplotlib.figure
+from typing import Optional
+
+import matplotlib.pyplot as plt
+from matplotlib.axes import Axes
+from matplotlib.figure import Figure
 
 
 class SimplePlottingAxes:
     def __init__(self,
-                 ax: 'matplotlib.axes.Axes' = None,
+                 ax: Optional[Axes] = None,
                  show: bool = False,
                  filename: str = None) -> None:
         self.ax = ax
         self.show = show
         self.filename = filename
-        self.figure = None
+        self.figure: Optional[Figure] = None
 
-    def __enter__(self) -> 'matplotlib.axes.Axes':
+    def __enter__(self) -> Axes:
         if self.ax is None:
-            import matplotlib.pyplot as plt
             self.figure, self.ax = plt.subplots()
         else:
             self.figure = self.ax.get_figure()
